package ij.text;

import java.awt.*;
import java.io.*;
import java.awt.event.*;
import ij.*;
import ij.io.*;

/** Displays text in a window. */
public class TextWindow extends Frame {

	private TextPanel textPanel;

	/**
	Opens a new text window with the title 'title'
	and initially containing 'str'.
	*/
	public TextWindow(String title, String str, int width, int height) {
		super(title);
		enableEvents(AWTEvent.WINDOW_EVENT_MASK);
		textPanel = new TextPanel();
		textPanel.setTitle(title);
		add("Center", textPanel);
		textPanel.append(str);
		setSize(width, height);
		setVisible(true);
	}

	/**
	Opens a new text window containing the contents
	of the text file specified by 'path'.
	*/
	public TextWindow(String path, int width, int height) {
		super("");
		enableEvents(AWTEvent.WINDOW_EVENT_MASK);
		textPanel = new TextPanel();
		add("Center", textPanel);
		if (openFile(path)) {
			setSize(width, height);
			setVisible(true);
		} else
			dispose();
	}
	
	public void append(String s) {
		textPanel.append(s);
	}
	
	public void setFont(Font font) {
		textPanel.setFont(font);
	}
  
	boolean openFile(String path) {
		OpenDialog od = new OpenDialog("Open Text File...", path);
		String directory = od.getDirectory();
		String name = od.getFileName();
		if (name==null)
			return false;
		path = directory + name;
		
		IJ.showStatus("Opening: " + path);
		try {
			BufferedReader r = new BufferedReader(new FileReader(directory + name));
			load(r);
		}
		catch (Exception e) {
			IJ.error(e.getMessage());
			return true;
		}
		textPanel.setTitle(name);
		setTitle(name);
		IJ.showStatus("");
		return true;
	}

	public void load(BufferedReader in) throws IOException {
		int count=0;
		while (true) {
			String s=in.readLine();
			if (s==null) break;
			textPanel.appendLine(s);
		}
	}

	public void processWindowEvent(WindowEvent e) {
		super.processWindowEvent(e);
		if (e.getID()==WindowEvent.WINDOW_CLOSING) {	
			setVisible(false);
			dispose();
			textPanel.flush();
		}
	}
}